summaryrefslogtreecommitdiff
path: root/build-openwrt-dev.sh
diff options
context:
space:
mode:
authorLudovic Pouzenc <ludovic@pouzenc.fr>2017-06-21 21:40:10 +0200
committerLudovic Pouzenc <ludovic@pouzenc.fr>2017-06-21 21:40:10 +0200
commit3a1d9159e1a22b02f5f3a28ec79e1f4da1f7740e (patch)
treee3557f5fbc098e477ad4c94a3e6f20f1747306d4 /build-openwrt-dev.sh
parent1c34ed8a1c6d668d1881ad8f96e5d99c91ead6a0 (diff)
downloadchd_openwrt-3a1d9159e1a22b02f5f3a28ec79e1f4da1f7740e.zip
chd_openwrt-3a1d9159e1a22b02f5f3a28ec79e1f4da1f7740e.tar.gz
chd_openwrt-3a1d9159e1a22b02f5f3a28ec79e1f4da1f7740e.tar.bz2
Improved previous tries with LEDE
- local mirroring of needed .ipk - little improovement of "profile" related legacy code (needs deeper changes)
Diffstat (limited to 'build-openwrt-dev.sh')
-rwxr-xr-xbuild-openwrt-dev.sh59
1 files changed, 8 insertions, 51 deletions
diff --git a/build-openwrt-dev.sh b/build-openwrt-dev.sh
index 41e4129..7a897c0 100755
--- a/build-openwrt-dev.sh
+++ b/build-openwrt-dev.sh
@@ -1,21 +1,23 @@
#!/bin/bash
#
# Work derived from ./quick_740n_ttn_bb.sh (Laurent Guerby <laurent@guery.net>)
+# Renamed from "CHD OpenWRT" to "CHD LEDE" on 2017-06-21
#
-# Copyright 2016 Ludovic Pouzenc <ludovic@pouzenc.fr>
+# Copyright 2017 Ludovic Pouzenc <ludovic@pouzenc.fr>
+# Copyright 2017 Nicolas Goaziou <mail@nicolasgoaziou.fr>
#
# CHD OpenWRT is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# CHD OpenWRT is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
-# along with CHD OpenWRT. If not, see <http://www.gnu.org/licenses/>.
+# along with CHD LEDE. If not, see <http://www.gnu.org/licenses/>.
#
echo -n "$0 - " ; date
@@ -99,20 +101,6 @@ if [ ! -f "$BUILD_DIR/Makefile" ]; then
wget -O "$CACHE_DIR/$ORIG_TARBALL" "$ORIG_URL"
fi
tar -x -C "$BUILD_DIR/" --strip-components=1 -f "$CACHE_DIR/$ORIG_TARBALL"
- # Hotfix about "logd" package not availble on chaos-calmer
-# patch -d "$BUILD_DIR/" -p1 <<"EOT"
-# --- a/include/target.mk 2017-04-01 22:00:23.000000000 +0200
-# +++ b/include/target.mk 2017-04-03 20:01:23.620028730 +0200
-# @@ -12,7 +12,7 @@
-# DEVICE_TYPE?=router
-
-# # Default packages - the really basic set
-# -DEFAULT_PACKAGES:=base-files libc libgcc busybox dropbear mtd uci opkg netifd fstools logd
-# +DEFAULT_PACKAGES:=base-files libc libgcc busybox dropbear mtd uci opkg netifd fstools
-# # For nas targets
-# DEFAULT_PACKAGES.nas:=block-mount fdisk lsblk mdadm
-# # For router targets
-# EOT
fi
cd "$BUILD_DIR/" || exit 5
@@ -123,23 +111,8 @@ mkdir -p extra_files/etc/config extra_files/etc/dropbear extra_files/etc/hotplug
# Prepare Openwrt config file #
###############################
-# # Use local replication of repositories
-# cat > repositories.conf <<"EOT"
-# ## Place your custom repositories here, they must match the architecture and version.
-# # src/gz chaos_calmer http://downloads.openwrt.org/chaos_calmer/15.05.1/ar71xx/generic/packages
-# # src custom file:///usr/src/openwrt/bin/ar71xx/packages
-
-# ## Remote package repositories
-# src/gz chaos_calmer_base http://localhost/openwrt/chaos_calmer/15.05.1/ar71xx/generic/packages/base
-# src/gz chaos_calmer_luci http://localhost/openwrt/chaos_calmer/15.05.1/ar71xx/generic/packages/luci
-# #src/gz chaos_calmer_packages http://localhost/openwrt/chaos_calmer/15.05.1/ar71xx/generic/packages/packages
-# src/gz chaos_calmer_routing http://localhost/openwrt/chaos_calmer/15.05.1/ar71xx/generic/packages/routing
-# #src/gz chaos_calmer_telephony http://localhost/openwrt/chaos_calmer/15.05.1/ar71xx/generic/packages/telephony
-# #src/gz chaos_calmer_management http://localhost/openwrt/chaos_calmer/15.05.1/ar71xx/generic/packages/management
-
-# ## This is the local package repository, do not remove!
-# src imagebuilder file:packages
-# EOT
+# Use local replication of repositories
+sed --in-place -e 's#downloads.lede-project.org#localhost/lede-project#' repositories.conf
cat > extra_files/etc/dropbear/authorized_keys <<EOF
ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQCuRKy/uRhwFvR3JrCp2NKY0HUPl0m7INUjY9wemmEGA6pSH/9zb+MLX9ZfuDVo6gkMI2YZzdpwAZ7KE2tajDXHHl+KiycY3lcQizgQt3usxf7Eqz3pTWtZBOjrHs3hRloPugg8KXA8Sxko03f68v8lfUw+Kj4LHmnnozJc8Hxde3GjkFbyL9c9Z5rSYG82H217RWaSDnjYso9wyBZYkjTe6vu88fWls3+ZL8p8NdrgqMFO7C+zV38Mgk/G3PkC9SYdobgy58Cm/06jehWonuafZ6bXTH1J3qjogbcGfewNx4H4E7Lf1nl6UTdbAC24tZu3c/UXZQzND+yRRK1r0zen lpouzenc@ttn
@@ -390,22 +363,6 @@ cat > extra_files/etc/hotplug.d/button/01onoff <<"EOF"
}
EOF
-# cat > extra_files/etc/banner <<"EOF"
-# _______ ________ __
-# | |.-----.-----.-----.| | | |.----.| |_
-# | - || _ | -__| || | | || _|| _|
-# |_______|| __|_____|__|__||________||__| |____|
-# |__| W I R E L E S S F R E E D O M
-# -----------------------------------------------------
-# CHAOS CALMER (15.05.1, 9a1fd3e 2017-03-09)
-# -----------------------------------------------------
-# * 1 1/2 oz Gin Shake with a glassful
-# * 1/4 oz Triple Sec of broken ice and pour
-# * 3/4 oz Lime Juice unstrained into a goblet.
-# * 1 1/2 oz Orange Juice
-# * 1 tsp. Grenadine Syrup
-# -----------------------------------------------------
-# EOF
#######################
# Build Openwrt image #
@@ -1,21 +1,23 @@
#
-# CHD OpenWRT is free software: you can redistribute it and/or modify
+# CHD LEDE is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
@@ -1,21 +1,23 @@
# (at your option) any later version.
#
-# CHD OpenWRT is distributed in the hope that it will be useful,
+# CHD LEDE is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the